

class Attributes:
    def __init__(self, instance):
        self.instance = instance

    def get_members(self):
        return [
            attr for attr in dir(self.instance)
            if not callable(getattr(self.instance, attr)) and not attr.startswith("__")
        ]

    def get_attribute(self, member):
        return getattr(self.instance, member)

    def get_typename(self, member):
        return type(self.get_attribute(member)).__name__

    def set_value(self, member, value):
        setattr(self.instance, member, value)



import unittest

from autofaker import Autodata


class SimpleClass:
    id = 123
    text = 'test'


class NestedClass:
    id = 123
    text = 'test'
    inner = SimpleClass()


class DoubleNestedClass:
    id = 123
    text = 'test'
    inner = NestedClass()


class AnonymousNestedClassTestCase(unittest.TestCase):

    def test_create_nested_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(NestedClass))

    def test_create_nested_class_returns_instance(self):
        self.assertIsInstance(Autodata.create(NestedClass), NestedClass)

    def test_create_nested_class_returns_instance_with_nested_not_none(self):
        self.assertIsNotNone(Autodata.create(NestedClass).inner)

    def test_create_nested_class_returns_instance_with_new_nested_instance(self):
        result = Autodata.create(NestedClass)
        self.assertNotEqual(result.id, NestedClass().id)
        self.assertNotEqual(result.inner.id, SimpleClass().id)
        self.assertNotEqual(result.inner.text, SimpleClass().text)


class AnonymousDoubleNestedClassTestCase(unittest.TestCase):

    def test_create_nested_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(DoubleNestedClass))

    def test_create_nested_class_returns_instance(self):
        self.assertIsInstance(Autodata.create(DoubleNestedClass), DoubleNestedClass)

    def test_create_nested_class_returns_instance_with_nested_not_none(self):
        self.assertIsNotNone(Autodata.create(DoubleNestedClass).inner)

    def test_create_nested_class_returns_instance_with_new_nested_instance(self):
        result = Autodata.create(DoubleNestedClass)
        self.assertNotEqual(result.id, DoubleNestedClass().id)
        self.assertNotEqual(result.inner, NestedClass())

    def test_create_nested_class_returns_instance_with_new_double_nested_instance(self):
        result = Autodata.create(DoubleNestedClass)
        self.assertNotEqual(result.id, DoubleNestedClass().id)
        self.assertNotEqual(result.inner.inner.id, SimpleClass().id)
        self.assertNotEqual(result.inner.inner.text, SimpleClass().text)



import unittest
from datetime import datetime, date

from autofaker import Autodata


class AnonymousDatetimeTestCase(unittest.TestCase):
    def test_create_datetime_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(datetime))

    def test_create_datetime_returns_not_type(self):
        self.assertNotIsInstance(Autodata.create(datetime), type)

    def test_create_datetime_returns_datetime(self):
        self.assertIsInstance(Autodata.create(datetime), datetime)


class AnonymousDateTestCase(unittest.TestCase):
    def test_create_date_returns_not_none(self):
        self.assertIsNotNone(Autodata.create(date))

    def test_create_date_returns_not_type(self):
        self.assertNotIsInstance(Autodata.create(date), type)

    def test_create_date_returns_date(self):
        self.assertIsInstance(Autodata.create(date), date)





import unittest
from abc import abstractmethod

from autofaker import Autodata


class CreateTestCase(unittest.TestCase):
    @abstractmethod
    def getType(self):
        pass

    def test_create_returns_not_none(self):
        if self.getType() is None:
            return
        self.assertIsNotNone(Autodata.create(self.getType()))

    def test_create_returns_not_type(self):
        if self.getType() is None:
            return
        self.assertNotIsInstance(Autodata.create(self.getType()), type)

    def test_create_returns_not_default(self):
        if self.getType() is None or self.getType() is bool:
            return
        self.assertNotEqual(Autodata.create(self.getType()), self.getType()())


class AnonymousIntegerTestCase(CreateTestCase):
    def getType(self):
        return int


class AnonymousStringTestCase(CreateTestCase):
    def getType(self):
        return str


class AnonymousFloatTestCase(CreateTestCase):
    def getType(self):
        return float


class AnonymousBooleanTestCase(CreateTestCase):
    def getType(self):
        return bool





from faker import Faker

from autofaker.attributes import Attributes
from autofaker.base import TypeDataGeneratorBase
from autofaker.builtins import StringGenerator

faker = Faker()


def generate(field_name: str):
    try:
        attributes = Attributes(faker)
        func = attributes.get_attribute(field_name)
        return func()
    except AttributeError:
        return None


class FakeStringGenerator(TypeDataGeneratorBase):
    def __init__(self, field_name: str):
        self.field_name = field_name

    def generate(self):
        fake = generate(self.field_name)
        return fake if fake is not None else StringGenerator().generate()


class FakeIntegerGenerator(TypeDataGeneratorBase):
    def generate(self):
        return faker.random_int()




import unittest

from autofaker import Autodata


class SimpleClass:
    id = 123
    text = 'test'


class NestedWithCollectionClass:
    id = 123
    text = 'test'
    inner = [SimpleClass(), SimpleClass()]


class NestedWithNestedCollectionClass:
    id = 123
    text = 'test'
    inner = [NestedWithCollectionClass(), NestedWithCollectionClass()]


class AnonymousNestedClassWithCollectionTestCase(unittest.TestCase):

    def test_create_many_nested_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create_many(NestedWithCollectionClass))

    def test_create_many_nested_class_returns_list(self):
        self.assertIsInstance(Autodata.create_many(NestedWithCollectionClass), list)

    def test_create_many_nested_class_returns_instances_with_nested_not_none(self):
        result = Autodata.create_many(NestedWithCollectionClass)
        for item in result:
            self.assertIsNotNone(item.inner)

    def test_create_many_nested_class_returns_instances_with_nested_not_empty(self):
        result = Autodata.create_many(NestedWithCollectionClass)
        for item in result:
            self.assertNotEqual(0, len(item.inner))

    def test_create_many_nested_class_returns_instances_with_new_nested_instance(self):
        result = Autodata.create_many(NestedWithCollectionClass)
        for item in result:
            self.assertNotEqual(item.id, NestedWithCollectionClass().id)
            for cls in item.inner:
                self.assertIsNotNone(cls)
                self.assertNotEqual(cls.id, SimpleClass().id)
                self.assertNotEqual(cls.text, SimpleClass().text)


class AnonymousNestedClassWithNestedCollectionTestCase(unittest.TestCase):

    def test_create_many_nested_class_returns_not_none(self):
        self.assertIsNotNone(Autodata.create_many(NestedWithCollectionClass))

    def test_create_many_nested_class_returns_list(self):
        self.assertIsInstance(Autodata.create_many(NestedWithCollectionClass), list)

    def test_create_many_nested_class_returns_instances_with_inner_not_none(self):
        result = Autodata.create_many(NestedWithNestedCollectionClass)
        for item in result:
            self.assertIsNotNone(item.inner)

    def test_create_many_nested_class_returns_instances_with_inner_not_empty(self):
        result = Autodata.create_many(NestedWithNestedCollectionClass)
        for item in result:
            self.assertNotEqual(0, len(item.inner))

    def test_create_many_nested_class_returns_instances_with_nested_inner_not_empty(self):
        result = Autodata.create_many(NestedWithNestedCollectionClass)
        for item in result:
            for cls in item.inner:
                self.assertNotEqual(0, len(cls.inner))

    def test_create_many_nested_class_returns_instances_with_new_nested_instances(self):
        result = Autodata.create_many(NestedWithNestedCollectionClass)
        for root in result:
            self.assertNotEqual(root.id, NestedWithNestedCollectionClass().id)
            self.assertNotEqual(root.text, NestedWithNestedCollectionClass().text)
            for inner in root.inner:
                self.assertNotEqual(inner.id, NestedWithCollectionClass().id)
                self.assertNotEqual(inner.text, NestedWithCollectionClass().text)
                for nested_inner in inner.inner:
                    self.assertNotEqual(nested_inner.id, SimpleClass().id)
                    self.assertNotEqual(nested_inner.text, SimpleClass().text)



import sys
import unittest

from autofaker import Autodata


class StaffTests(unittest.TestCase):

    def test_create_pandas_dataframe_returns_not_none(self):
        pdf = Autodata.create_pandas_dataframe(SimpleClass)
        self.assertIsNotNone(pdf)

    @unittest.skipIf(sys.platform.startswith("win"), "requires Windows")
    def test_create_spark_dataframe_returns_not_none(self):
        df = Autodata.create_spark_dataframe(SimpleClass)
        self.assertIsNotNone(df)


class SimpleClass:
    id = 123
    text = 'test'



"""
Provides classes for anonymous object creation to help minimize the setup/arrange phase when writing unit tests
"""

import typing
from typing import List

from numpy import ufunc
from pyspark.sql import DataFrame, SparkSession

from autofaker.dataframe import PandasDataFrameGenerator, SparkDataFrameGenerator
from autofaker.generator import TypeDataGenerator


class Autodata:
    """
    Provides anonymous object creation functions to help minimize the setup/arrange phase when writing unit tests
    """

    @staticmethod
    def create(t, use_fake_data: bool = False):
        """
        Creates an anonymous variable of the requested type

        :param use_fake_data:
        :type t: object
        """
        return TypeDataGenerator.create(t, use_fake_data=use_fake_data).generate()

    @staticmethod
    def create_many(t, size: int = 3, use_fake_data: bool = False) -> List[typing.Any]:
        """
        Creates a list of anonymous variables of the requested type using the specified length (default 3)

        :param use_fake_data:
        :type size: int
        :type t: object
        """
        items = []
        for i in range(size):
            items.append(Autodata.create(t, use_fake_data=use_fake_data))
        return items

    @staticmethod
    def create_pandas_dataframe(t, rows: int = 3, use_fake_data: bool = False):
        """
        Create a Pandas DataFrame containing anonymous data with the specified number of rows (default 3)

        :param use_fake_data:
        :type rows: int
        :type t: object
        """
        return PandasDataFrameGenerator(t, rows, use_fake_data=use_fake_data).generate()

    @staticmethod
    def create_spark_dataframe(t, rows: int = 3, use_fake_data: bool = False) -> DataFrame:
        """
        Create a Spark DataFrame containing anonymous data with the specified number of rows (default 3)

        :param use_fake_data:
        :type rows: int
        :type t: object
        """
        return SparkDataFrameGenerator(t, rows, use_fake_data=use_fake_data).generate()



import datetime
import random

from autofaker.base import TypeDataGeneratorBase


class DatetimeGenerator(TypeDataGeneratorBase):
    def generate(self):
        year = datetime.date.today().year
        return datetime.datetime(random.randint(year - 10, year + 10),
                                 random.randint(1, 12),
                                 random.randint(1, 28),
                                 random.randint(0, 23),
                                 random.randint(0, 59),
                                 random.randint(0, 59),
                                 random.randint(0, 999))


class DateGenerator(TypeDataGeneratorBase):
    def generate(self):
        year = datetime.date.today().year
        return datetime.datetime(random.randint(year - 10, year + 10),
                                 random.randint(1, 12),
                                 random.randint(1, 28))

